@@ -264,21 +264,17 @@ class LedgerApiRequestDispatcher(RequestDispatcher):
                     message.transaction_digest.body,
                     raise_on_try=True,
                 )
-            except Exception as e:  # pylint: disable=broad-except  # pragma: nocover
-                return self.get_error_message(e, api, message, dialogue)
+            except Exception as e:  # pylint: disable=broad-except
+                _default_logger.warning(e)
+                transaction_receipt = None
 
             if transaction_receipt is not None:
                 is_settled = api.is_transaction_settled(transaction_receipt)
             attempts += 1
             time.sleep(retry_timeout * attempts)
         attempts = 0
-        try:
-            transaction = api.get_transaction(
-                message.transaction_digest.body, raise_on_try=True
-            )
-        except Exception as e:  # pylint: disable=broad-except  # pragma: nocover
-            return self.get_error_message(e, api, message, dialogue)
 
+        transaction = None
         while (
             transaction is None
             and attempts < retry_attempts
@@ -288,13 +284,14 @@ class LedgerApiRequestDispatcher(RequestDispatcher):
                 transaction = api.get_transaction(
                     message.transaction_digest.body, raise_on_try=True
                 )
-            except Exception as e:  # pylint: disable=broad-except  # pragma: nocover
-                return self.get_error_message(e, api, message, dialogue)
+            except Exception as e:  # pylint: disable=broad-except
+                _default_logger.warning(e)
+                transaction = None
 
             attempts += 1
             time.sleep(retry_timeout * attempts)
 
-        if not is_settled:  # pragma: nocover
+        if not is_settled:
             response = self.get_error_message(
                 ValueError("Transaction not settled within timeout"),
                 api,
@@ -305,7 +302,7 @@ class LedgerApiRequestDispatcher(RequestDispatcher):
             response = self.get_error_message(
                 ValueError("No transaction_receipt returned"), api, message, dialogue
             )
-        elif transaction is None:  # pragma: nocover
+        elif transaction is None:
             response = self.get_error_message(
                 ValueError("No transaction returned"), api, message, dialogue
             )
