@@ -118,7 +118,7 @@ from packages.valory.skills.apy_estimation_abci.tools.queries import (
 
 
 NON_INDEXED_BLOCK_RE = (
-    r"Failed to decode `block.number` value: `subgraph QmPJbGjktGa7c4UYWXvDRajPxpuJBSZxeQK5siNT3VpthP has only "
+    r"Failed to decode `block.number` value: `subgraph \w{46} has only "
     r"indexed up to block number (\d+) and data for block number \d+ is therefore not yet available`"
 )
 
@@ -128,7 +128,7 @@ class APYEstimationBaseBehaviour(BaseBehaviour, ABC):
 
     @property
     def synchronized_data(self) -> SynchronizedData:
-        """Return the synchronized data."""
+        """Return the synchronized data data."""
         return cast(SynchronizedData, super().synchronized_data)
 
     @property
