@@ -43,3 +43,15 @@ hash_file  # unused function (autonomy/cli/hash.py:94)
 _create_or_update_from_json  # unused method (autonomy/configurations/base.py:175)
 help  # unused attribute (autonomy/cli/core.py:41)
 DEFAULT_ABCI_BUILD_DIR  # unused variable (autonomy/deploy/constants.py:105)
+build_images  # unused function (autonomy/cli/deploy.py:187)
+execinfo  # unused variable (autonomy/data/Dockerfiles/tendermint/app.py:100)
+get_params  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:142)
+update_params  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:155)
+gentle_reset  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:187)
+app_hash  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:197)
+handle_notfound  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:236)
+handle_server_error  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:242)
+create_server  # unused function (autonomy/data/Dockerfiles/tendermint/app.py:251)
+call_vote  # unused function (autonomy/data/Dockerfiles/dev/watcher.py:54)
+wait_for_votes  # unused function (autonomy/data/Dockerfiles/dev/watcher.py:67)
+on_any_event  # unused method (autonomy/data/Dockerfiles/dev/watcher.py:166)
