@@ -18,33 +18,33 @@
 # ------------------------------------------------------------------------------
 
 """Integration tests for the valory/register_reset skill."""
+
 import pytest
 from aea.configurations.data_types import PublicId
 
-from tests.test_agents.base import (
-    BaseTestEnd2EndAgentCatchup,
-    BaseTestEnd2EndNormalExecution,
+from tests.test_agents.base import BaseTestEnd2EndExecution, RoundChecks
+
+
+HAPPY_PATH = (
+    RoundChecks("registration_startup"),
+    RoundChecks("registration", n_periods=3),
+    RoundChecks("reset_and_pause", n_periods=4),
 )
 
 
-# round check log messages of the happy path
-EXPECTED_ROUND_LOG_COUNT = {
-    "registration_startup": 1,
-    "registration": 3,
-    "reset_and_pause": 4,
-}
-
-
+@pytest.mark.e2e
+@pytest.mark.integration
+@pytest.mark.flaky(reruns=3)
 @pytest.mark.parametrize("nb_nodes", (4,))
-class TestTendermintStartup(BaseTestEnd2EndNormalExecution):
+class TestTendermintStartup(BaseTestEnd2EndExecution):
     """Test the ABCI register-reset skill with 4 agents starting up."""
 
     agent_package = "valory/register_reset:0.1.0"
     skill_package = "valory/register_reset_abci:0.1.0"
-    round_check_strings_to_n_periods = {
-        "registration_startup": 1,
-        "reset_and_pause": 1,
-    }
+    happy_path = (
+        RoundChecks("registration_startup"),
+        RoundChecks("reset_and_pause"),
+    )
     wait_to_finish = 60
     __args_prefix = f"vendor.valory.skills.{PublicId.from_str(skill_package).name}.models.params.args"
     extra_configs = [
@@ -55,13 +55,16 @@ class TestTendermintStartup(BaseTestEnd2EndNormalExecution):
     ]
 
 
+@pytest.mark.e2e
+@pytest.mark.integration
+@pytest.mark.flaky(reruns=3)
 @pytest.mark.parametrize("nb_nodes", (4,))
-class TestTendermintReset(BaseTestEnd2EndNormalExecution):
+class TestTendermintReset(BaseTestEnd2EndExecution):
     """Test the ABCI register-reset skill with 4 agents when resetting Tendermint."""
 
     agent_package = "valory/register_reset:0.1.0"
     skill_package = "valory/register_reset_abci:0.1.0"
-    round_check_strings_to_n_periods = EXPECTED_ROUND_LOG_COUNT
+    happy_path = HAPPY_PATH
     wait_to_finish = 200
     __reset_tendermint_every = 1
     __args_prefix = f"vendor.valory.skills.{PublicId.from_str(skill_package).name}.models.params.args"
@@ -78,8 +81,11 @@ class TestTendermintReset(BaseTestEnd2EndNormalExecution):
     ]
 
 
+@pytest.mark.e2e
+@pytest.mark.integration
+@pytest.mark.flaky(reruns=3)
 @pytest.mark.parametrize("nb_nodes", (4,))
-class TestTendermintResetInterrupt(BaseTestEnd2EndAgentCatchup):
+class TestTendermintResetInterrupt(BaseTestEnd2EndExecution):
     """Test the ABCI register-reset skill with 4 agents when an agent gets interrupted on Tendermint reset."""
 
     agent_package = "valory/register_reset:0.1.0"
@@ -90,7 +96,7 @@ class TestTendermintResetInterrupt(BaseTestEnd2EndAgentCatchup):
     restart_after = 1
     __reset_tendermint_every = 1
     stop_string = f"Entered in the 'reset_and_pause' round for period {__reset_tendermint_every - 1}"
-    round_check_strings_to_n_periods = EXPECTED_ROUND_LOG_COUNT
+    happy_path = HAPPY_PATH
 
     __args_prefix = f"vendor.valory.skills.{PublicId.from_str(skill_package).name}.models.params.args"
     # reset every `__reset_tendermint_every` rounds
@@ -105,7 +111,12 @@ class TestTendermintResetInterrupt(BaseTestEnd2EndAgentCatchup):
         },
     ]
 
+    n_terminal = 1
 
+
+@pytest.mark.e2e
+@pytest.mark.integration
+@pytest.mark.flaky(reruns=3)
 class TestTendermintResetInterruptNoRejoin(TestTendermintResetInterrupt):
     """
     Test a Tendermint reset case for the ABCI register-reset skill.
@@ -117,5 +128,5 @@ class TestTendermintResetInterruptNoRejoin(TestTendermintResetInterrupt):
     wait_to_finish = 200
     # set the restart to a value so that the agent never rejoins, in order to test the impact to the rest of the agents
     restart_after = wait_to_finish
-    # check if we manage to reset with Tendermint with the rest of the agents; 3rd agent will not rejoin in this test
-    exclude_from_checks = [3]
+    # check if we manage to reset with Tendermint with the rest of the agents; first agent will not rejoin in this test
+    exclude_from_checks = [0]
