@@ -54,7 +54,7 @@ STRICT_CHECK_STRINGS = (
     log_messages.collection_complete.value,
     log_messages.request_update.value,
     log_messages.response_update.value,
-    "Entered in the 'finished_registration' round for period 0",
+    "local height == remote height; continuing execution...",
 )
 
 
@@ -74,6 +74,10 @@ class RegistrationStartUpTestConfig(
             "dotted_path": f"{__args_prefix}.share_tm_config_on_startup",
             "value": True,
         },
+        {
+            "dotted_path": f"vendor.valory.skills.{PublicId.from_str(skill_package).name}.is_abstract",
+            "value": False,
+        },
         {
             "dotted_path": f"{__args_prefix}.observation_interval",
             "value": 15,
