@@ -28,6 +28,7 @@ from typing import Any, Dict, Optional, Set, Tuple, Type
 from unittest import mock
 from unittest.mock import MagicMock
 
+import hypothesis
 import pytest
 from aea.exceptions import AEAEnforceError
 from aea_ledger_ethereum import EthereumCrypto
@@ -331,6 +332,7 @@ def test_verify_transaction_negative_case(*_mocks: Any) -> None:
         transaction.verify("")
 
 
+@hypothesis.settings(deadline=2000)
 @given(
     dictionaries(
         keys=text(),
@@ -1164,6 +1166,16 @@ class TestAbciApp:
         """Set up the test."""
         self.abci_app = AbciAppTest(MagicMock(), MagicMock(), MagicMock())
 
+    @pytest.mark.parametrize("flag", (True, False))
+    def test_is_abstract(self, flag: bool) -> None:
+        """Test `is_abstract` property."""
+
+        class CopyOfAbciApp(AbciAppTest):
+            """Copy to avoid side effects due to state change"""
+
+        CopyOfAbciApp._is_abstract = flag
+        assert CopyOfAbciApp.is_abstract() is flag
+
     def test_initial_round_cls_not_set(self) -> None:
         """Test when 'initial_round_cls' is not set."""
 
